@@ -8,7 +8,7 @@ class Log(core.models.Log):
     metodo = models.CharField(max_length=30, null=True)
     ip = models.GenericIPAddressField(null=True)
     path = models.CharField(max_length=500, null=True)
-    session_id = models.CharField(max_length=200, null=True)
+    session_key = models.CharField(max_length=200, null=True)
 
     class Meta:
         #db_table = u'"log\".\"log"'
